@@ -6,7 +6,7 @@
 #' is not detrended so results once you apply an STL decompostion
 #' will vary from the unajusted seasonal plot.
 #' @param df Long data frame with columns series, date and value
-#' @param title Your chart title
+#' @param title Default is a blank space returning the unique value in df$series.
 #' @param per
 #' Frequency of seasonality "yearweek" (DEFAULT). "yearmonth", "yearquarter"
 #' @param output
@@ -22,16 +22,18 @@
 #' @export chart_zscore
 #' @author Philippe Cote
 #' @examples
-#' chart_zscore(df = ng_storage, title = "NG Storage Z Score",
-#' per = "yearweek", output = "stl", chart = "seasons")
-#' chart_zscore(df = ng_storage, title = "NG Storage Z Score",
-#' per = "yearweek", output = "stats", chart = "seasons")
-#' chart_zscore(df = ng_storage, title = "NG Storage Z Score",
-#' per = "yearweek", output = "zscore", chart = "seasons")
-#' chart_zscore(df = ng_storage, title = "NG Storage Z Score",
-#' per = "yearweek", output = "seasonal", chart = "seasons")
+#' \dontrun{
+#' df <- eiaStocks %>% dplyr::filter(series == "NGLower48")
+#' title <- "NGLower48"
+#' chart_zscore(df = df, title = " ",per = "yearweek", output = "stl", chart = "seasons")
+#' chart_zscore(df = df, title = " ",per = "yearweek", output = "stats", chart = "seasons")
+#' chart_zscore(df = df, title = " ",per = "yearweek", output = "zscore", chart = "seasons")
+#' chart_zscore(df = df, title = " ",per = "yearweek", output = "seasonal", chart = "seasons")
+#' }
 
 chart_zscore <- function(df = df, title = "NG Storage Z Score", per = "yearweek", output = "zscore", chart = "seasons") {
+
+  if (nchar(title) == 0) {title <- unique(df$series)}
   if (!output %in% c("zscore","seasonal","stats","stl")) {stop(print("Incorrect output parameter"))}
   if (!per %in% c("yearweek","yearmonth","yearquarter")) {stop(print("Incorrect period parameter"))}
   if (per %in% c("yearweek","yearquarter")) {s = 7 ; e = 8}
@@ -40,64 +42,64 @@ chart_zscore <- function(df = df, title = "NG Storage Z Score", per = "yearweek"
   #s <- list(freq = ~yearweek(.))
 
   if (output == "stl") {
-      x <- df %>%
-        tsibble::as_tsibble(key=series, index = date) %>%
-        tsibble::group_by_key()
-      if (per %in% c("yearweek")) {x <- x %>% tsibble::index_by(freq = ~yearweek(.))}
-      if (per %in% c("yearmonth")) {x <- x %>% tsibble::index_by(freq = ~yearmonth(.))}
-      if (per %in% c("yearquarter")) {x <- x %>% tsibble::index_by(freq = ~yearquarter(.))}
-      #tsibble::index_by(freq = ~do.call(per,args=list(.))) %>%
-      x <- x %>% dplyr::summarise(value = mean(value)) %>%
-        fabletools::model(feasts::STL(value ~ season(window = Inf))) %>%
-        fabletools::components() %>%
-        ggplot2::autoplot()
-      return(x)
-    }
+    x <- df %>%
+      tsibble::as_tsibble(key = series, index = date) %>%
+      tsibble::group_by_key()
+    if (per %in% c("yearweek")) {x <- x %>% tsibble::index_by(freq = ~yearweek(.))}
+    if (per %in% c("yearmonth")) {x <- x %>% tsibble::index_by(freq = ~yearmonth(.))}
+    if (per %in% c("yearquarter")) {x <- x %>% tsibble::index_by(freq = ~yearquarter(.))}
+    #tsibble::index_by(freq = ~do.call(per,args=list(.))) %>%
+    x <- x %>% dplyr::summarise(value = mean(value)) %>%
+      fabletools::model(feasts::STL(value ~ season(window = Inf))) %>%
+      fabletools::components() %>%
+      ggplot2::autoplot()
+    return(x)
+  }
 
   if (output == "stats") {
-      x <- rbind(df,df %>% dplyr::mutate(series = title)) %>%
-        tsibble::as_tsibble(key=series, index = date) %>%
-        tsibble::group_by_key() #%>%
-      if (per %in% c("yearweek")) {x <- x %>% tsibble::index_by(freq = ~yearweek(.))}
-      if (per %in% c("yearmonth")) {x <- x %>% tsibble::index_by(freq = ~yearmonth(.))}
-      if (per %in% c("yearquarter")) {x <- x %>% tsibble::index_by(freq = ~yearquarter(.))}
-      x <- x %>%  dplyr::summarise(value = mean(value)) %>%
-        fabletools::model(feasts::STL(value ~ season(window = Inf))) %>%
-        fabletools::components() %>%
-        dplyr::slice(1)
-      return(x)
-    }
-
-  df <- df %>%
+    x <- rbind(df,df %>% dplyr::mutate(series = title)) %>%
       tsibble::as_tsibble(key=series, index = date) %>%
       tsibble::group_by_key() #%>%
+    if (per %in% c("yearweek")) {x <- x %>% tsibble::index_by(freq = ~yearweek(.))}
+    if (per %in% c("yearmonth")) {x <- x %>% tsibble::index_by(freq = ~yearmonth(.))}
+    if (per %in% c("yearquarter")) {x <- x %>% tsibble::index_by(freq = ~yearquarter(.))}
+    x <- x %>%  dplyr::summarise(value = mean(value)) %>%
+      fabletools::model(feasts::STL(value ~ season(window = Inf))) %>%
+      fabletools::components() %>%
+      dplyr::slice(1)
+    return(x)
+  }
+
+  df <- df %>%
+    tsibble::as_tsibble(key=series, index = date) %>%
+    tsibble::group_by_key() #%>%
   if (per %in% c("yearweek")) {df <- df %>% tsibble::index_by(freq = ~yearweek(.))}
   if (per %in% c("yearmonth")) {df <- df %>% tsibble::index_by(freq = ~yearmonth(.))}
   if (per %in% c("yearquarter")) {df <- df %>% tsibble::index_by(freq = ~yearquarter(.))}
   df <- df %>%
-      #tsibble::index_by(freq = ~do.call(per,args=list(.))) %>%
-      dplyr::summarise(value = mean(value))
+    #tsibble::index_by(freq = ~do.call(per,args=list(.))) %>%
+    dplyr::summarise(value = mean(value))
   z <- df %>%
     fabletools::model(feasts::STL(value ~ season(window = Inf))) %>%
     fabletools::components() %>%
-      dplyr::transmute(per = as.numeric(do.call(stringr::str_sub,args=list(freq, start = s, end = e))),
-                       year = lubridate::year(freq),
-                       value=remainder) %>%
-      dplyr::as_tibble() %>%
-      dplyr::group_by(per) %>%
-      dplyr::summarise(u = mean(value), sigma = stats::sd(value))
+    dplyr::transmute(per = as.numeric(do.call(stringr::str_sub,args=list(freq, start = s, end = e))),
+                     year = lubridate::year(freq),
+                     value=remainder) %>%
+    dplyr::as_tibble() %>%
+    dplyr::group_by(per) %>%
+    dplyr::summarise(u = mean(value), sigma = stats::sd(value))
   x <- df %>%
     fabletools::model(feasts::STL(value ~ season(window = Inf))) %>%
     fabletools::components() %>%
-      dplyr::mutate(per = as.numeric(do.call(stringr::str_sub,args=list(freq, start = s, end = e)))) %>%
-      dplyr::left_join(z, by = c("per")) %>%
-      dplyr::mutate(z.score = (remainder - u) / sigma)
+    dplyr::mutate(per = as.numeric(do.call(stringr::str_sub,args=list(freq, start = s, end = e)))) %>%
+    dplyr::left_join(z, by = c("per")) %>%
+    dplyr::mutate(z.score = (remainder - u) / sigma)
 
   if (output == "seasonal") {
 
     if (chart == "seasons") {x <- df %>% feasts::gg_season(value)}
     if (chart == "series") {x <- df %>% feasts::gg_subseries(value)}
-    }
+  }
 
   if (output == "zscore") {
 
